from distutils.core import setup

setup(
    name = 'alay',
    packages = ['alay'],
    version = '1.2',
    description = 'Generate your text into Alay style.',
    author = 'Zul Hilmi',
    author_email = 'netspytux@gmail.com',
    url = 'https://github.com/HilmiZul/alay-generator',
    keywords = ['alay', 'alay generator', 'bahasa alay'],
    classifiers = [
      "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
